@@ -7,9 +7,10 @@ class WKTAdapter:
         self.srid = geom.srid
 
     def __eq__(self, other):
-        if not isinstance(other, WKTAdapter):
-            return False
-        return self.wkt == other.wkt and self.srid == other.srid
+        return (
+            isinstance(other, WKTAdapter) and
+            self.wkt == other.wkt and self.srid == other.srid
+        )
 
     def __hash__(self):
         return hash((self.wkt, self.srid))
